@@ -264,3 +264,6 @@ class IntegrationEnvironment:
 
 IntegrationEntryPoint = \
     Callable[[IntegrationEnvironment, IntegrationEvents], None]
+
+def getIntegrationLogger():
+    return logging.getLogger('integration')
